==> haskell-hs-bibutils-6.10.0.0-145-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hs-bibutils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hs-bibutils
version:              6.10.0.0
visibility:           public
id:                   hs-bibutils-6.10.0.0-BPQT5fc19PXH01rwVCVOGN
key:                  hs-bibutils-6.10.0.0-BPQT5fc19PXH01rwVCVOGN
license:              LicenseRef-GPL
maintainer:           Václav Haisman <vhaisman@gmail.com>
author:               Andrea Rossato
homepage:             https://github.com/wilx/hs-bibutils
synopsis:
    Haskell bindings to bibutils, the bibliography
    conversion utilities.

description:
    Haskell bindings to Chris Putnam'\''s bibutils, a
    library that interconverts between various
    bibliography formats using a common MODS-format
    XML intermediate.

    hs-bibutils is available under the GNU GPL license. See
    the LICENSE file for details.

    For more details about bibutils, please check:
    <http://sourceforge.net/p/bibutils/home/Bibutils/>.

    The package release number refers to the release number of
    the included bibutils library.

category:             Text
abi:                  85e2f02d9eb59d389d48e33859d58056
exposed:              True
exposed-modules:      Text.Bibutils
import-dirs:          /usr/lib/ghc-9.0.2/site-local/hs-bibutils-6.10.0.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hs-bibutils-6.10.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hs-bibutils
hs-libraries:         HShs-bibutils-6.10.0.0-BPQT5fc19PXH01rwVCVOGN
includes:             bibutils.h
depends:              base-4.15.1.0 syb-0.7.2.3-HnHI7NNT3Te1LokUqmgbA
haddock-interfaces:   /usr/share/doc/haskell-hs-bibutils/html/hs-bibutils.haddock
haddock-html:         /usr/share/doc/haskell-hs-bibutils/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hs-bibutils-6.10.0.0-146-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hs-bibutils.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hs-bibutils
version:              6.10.0.0
visibility:           public
id:                   hs-bibutils-6.10.0.0-D9tsMCMM71pLscBMmOMStS
key:                  hs-bibutils-6.10.0.0-D9tsMCMM71pLscBMmOMStS
license:              LicenseRef-GPL
maintainer:           Václav Haisman <vhaisman@gmail.com>
author:               Andrea Rossato
homepage:             https://github.com/wilx/hs-bibutils
synopsis:
    Haskell bindings to bibutils, the bibliography
    conversion utilities.

description:
    Haskell bindings to Chris Putnam'\''s bibutils, a
    library that interconverts between various
    bibliography formats using a common MODS-format
    XML intermediate.

    hs-bibutils is available under the GNU GPL license. See
    the LICENSE file for details.

    For more details about bibutils, please check:
    <http://sourceforge.net/p/bibutils/home/Bibutils/>.

    The package release number refers to the release number of
    the included bibutils library.

category:             Text
abi:                  7b5f3b5fee27d4840bd85b2214fc6fc1
exposed:              True
exposed-modules:      Text.Bibutils
import-dirs:          /usr/lib/ghc-9.0.2/site-local/hs-bibutils-6.10.0.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hs-bibutils-6.10.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hs-bibutils
hs-libraries:         HShs-bibutils-6.10.0.0-D9tsMCMM71pLscBMmOMStS
includes:             bibutils.h
depends:              base-4.15.1.0 syb-0.7.2.4-CrXKYIWYt0k5oYW5xy7ynG
haddock-interfaces:   /usr/share/doc/haskell-hs-bibutils/html/hs-bibutils.haddock
haddock-html:         /usr/share/doc/haskell-hs-bibutils/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
